@@ -68,7 +68,6 @@ from lino.modlib.cal import models as cal
 #~ from lino.modlib.uploads.models import UploadsByPerson
 from lino.core.dbutils import get_field
 from lino.core.dbutils import resolve_field
-#~ from lino.core.dbutils import range_filter
 from lino.core import actions
 from lino.core.constants import _handle_attr_name
 
@@ -420,7 +419,9 @@ The total monthly amount available for debts distribution."""))
                 return
             sar.setup_from(ar)
             chunks.append(E.h2(unicode(sar.get_title())))
-            chunks.append(ar.ui.table2xhtml(sar))
+            #~ chunks.append(ar.ui.table2xhtml(sar))
+            chunks.append(settings.SITE.ui.table2xhtml(sar))
+            #~ raise Exception("20130527")
             
         for grp in self.account_groups():
             render(self.entries_by_group(grp))
