@@ -24,7 +24,7 @@ import cgi
 import datetime
 
 from django.db import models
-#~ from django.db.models import Q
+from django.db.models import Q
 from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.utils.safestring import mark_safe
@@ -34,7 +34,7 @@ from django.utils import translation
 
 
 from lino import dd
-from lino.utils import dblogger
+from lino.utils import dblogger as logger
 #~ from lino.utils import printable
 from lino import mixins
 #~ from lino.modlib.contacts import models as contacts
@@ -157,7 +157,7 @@ class ContractEnding(dd.Model):
         
     name = models.CharField(_("designation"),max_length=200)
     use_in_isip = models.BooleanField(_("ISIP"),default=True)
-    use_in_jobs = models.BooleanField(_("Jobs"),default=True)
+    use_in_jobs = models.BooleanField(pcsw.JOBS_MODULE_LABEL,default=True)
     is_success = models.BooleanField(_("Success"),default=False)
     needs_date_ended = models.BooleanField(_("Require date ended"),default=False)
     
@@ -169,6 +169,12 @@ class ContractEndings(dd.Table):
     model = ContractEnding
     column_names = 'name *'
     order_by = ['name']
+    detail_layout = """
+    name
+    use_in_isip use_in_jobs is_success needs_date_ended
+    isip.ContractsByEnding 
+    jobs.ContractsByEnding
+    """
 
 #~ FUNCTION_ID_SECRETARY = 3
 #~ FUNCTION_ID_PRESIDENT = 16
@@ -234,6 +240,10 @@ class StudyTypes(dd.Table):
     #~ label = _('Study types')
     model = StudyType
     order_by = ["name"]
+    detail_layout = """
+    name id
+    ContractsByStudyType
+    """
 
 
 
@@ -476,44 +486,122 @@ dd.update_field(ContractBase,'signer1', default=default_signer1)
 dd.update_field(ContractBase,'signer2', default=default_signer2)
 
 
+class ContractEvents(dd.ChoiceList):
+    verbose_name = _("Observed event")
+    verbose_name_plural = _("Observed events")
+add = ContractEvents.add_item
+add('10', _("Started"),'started')
+add('20', _("Active"),'active')
+add('30', _("Ended"),'ended')
+add('40', _("Signed"),'signed')
+
+
 class ContractBaseTable(dd.Table):
     parameters = dict(
-      user = dd.ForeignKey(settings.SITE.user_model,blank=True),
-      show_past = models.BooleanField(_("past contracts"),default=True),
-      show_active = models.BooleanField(_("active contracts"),default=True),
-      show_coming = models.BooleanField(_("coming contracts"),default=True),
-      today = models.DateField(_("on"),blank=True,default=datetime.date.today),
+        user = dd.ForeignKey(settings.SITE.user_model,blank=True),
+        #~ show_past = models.BooleanField(_("past contracts"),default=True),
+        #~ show_active = models.BooleanField(_("active contracts"),default=True),
+        #~ show_coming = models.BooleanField(_("coming contracts"),default=True),
+        #~ today = models.DateField(_("on"),blank=True,default=datetime.date.today),
+      
+        start_date = models.DateField(_("Period from"),
+            blank=True,null=True,
+            help_text="""Date début de la période observée"""),
+        end_date = models.DateField(_("until"),
+            blank=True,null=True,
+            help_text="""Date fin de la période observée"""),
+        observed_event = ContractEvents.field(blank=True,default=ContractEvents.active),
+      
+        ending_success = dd.YesNo.field(_("Successfully ended"),
+            blank=True,help_text="""Contrats terminés avec succès."""),
+        ending = models.ForeignKey(ContractEnding,
+            blank=True,null=True,
+            help_text="""Nur Konventionen mit diesem Beendigungsgrund."""),
+        company = models.ForeignKey('contacts.Company',
+            blank=True,null=True,
+            help_text="""Nur Konventionen mit dieser Organisation als Drittpartner."""),
+      
     )
     
-    params_layout = """user type show_past show_active show_coming today"""
+    params_layout = """
+    user type start_date end_date observed_event
+    ending_success ending
+    """
     params_panel_hidden = True
     
+    #~ @classmethod
+    #~ def param_defaults(self,ar,**kw):
+        #~ kw = super(ContractBaseTable,self).param_defaults(ar,**kw)
+        #~ D = datetime.date
+        #~ kw.update(start_date = D.today())
+        #~ kw.update(end_date = D.today())
+        #~ return kw
+        
     @classmethod
-    def get_request_queryset(cls,rr):
-        #~ logger.info("20120608.get_request_queryset param_values = %r",rr.param_values)
-        qs = super(ContractBaseTable,cls).get_request_queryset(rr)
-        #~ user = rr.param_values.get('user',None)
-        if rr.param_values.user:
-            qs = qs.filter(user=rr.param_values.user)
-        if rr.param_values.type:
-            qs = qs.filter(type=rr.param_values.type)
-        today = rr.param_values.today or datetime.date.today()
-        #~ today = rr.param_values.get('today',None) or datetime.date.today()
-        #~ show_active = rr.param_values.get('show_active',True)
-        if today:
-            if not rr.param_values.show_active:
-                flt = range_filter(today,'applies_from','applies_until')
-                #~ logger.info("20120114 flt = %r",flt)
-                qs = qs.exclude(flt)
-            #~ show_past = rr.param_values.get('show_past',True)
-            if not rr.param_values.show_past:
-                qs = qs.exclude(applies_until__isnull=False,applies_until__lt=today)
-            #~ show_coming = rr.param_values.get('show_coming',True)
-            if not rr.param_values.show_coming:
-                qs = qs.exclude(applies_from__isnull=False,applies_from__gt=today)
+    def get_request_queryset(cls,ar):
+        #~ logger.info("20120608.get_request_queryset param_values = %r",ar.param_values)
+        qs = super(ContractBaseTable,cls).get_request_queryset(ar)
+        #~ user = ar.param_values.get('user',None)
+        if ar.param_values.user:
+            qs = qs.filter(user=ar.param_values.user)
+        if ar.param_values.type:
+            qs = qs.filter(type=ar.param_values.type)
+        if ar.param_values.company:
+            qs = qs.filter(company=ar.param_values.company)
+            
+        ce = ar.param_values.observed_event
+        if ar.param_values.start_date is None or ar.param_values.end_date is None:
+            period = None
+        else:
+            period = (ar.param_values.start_date, ar.param_values.end_date)
+        if ce and period is not None:
+            if ce == ContractEvents.ended:
+                #~ qs = qs.filter(Q(applies_until__lte=period[1]) | Q(date_ended__isnull=False,date_ended__lte=period[1]))
+                qs = qs.filter(dd.inrange_filter('applies_until',period)|dd.inrange_filter('date_ended',period))
+            elif ce == ContractEvents.started:
+                qs = qs.filter(dd.inrange_filter('applies_from',period))
+            elif ce == ContractEvents.signed:
+                qs = qs.filter(dd.inrange_filter('date_decided',period))
+            elif ce == ContractEvents.active:
+                f1 = Q(applies_until__isnull=True) | Q(applies_until__gte=period[0])
+                flt = f1 & (Q(date_ended__isnull=True) | Q(date_ended__gte=period[0]))
+                flt &= Q(applies_from__lte=period[1])
+                qs = qs.filter(flt)
+                #~ print 20130527, qs.query
+            else:
+                raise Exception(repr(ce))
+        #~ today = ar.param_values.today or datetime.date.today()
+        #~ if today:
+            #~ if not ar.param_values.show_active:
+                #~ flt = range_filter(today,'applies_from','applies_until')
+                #~ qs = qs.exclude(flt)
+            #~ if not ar.param_values.show_past:
+                #~ qs = qs.exclude(applies_until__isnull=False,applies_until__lt=today)
+            #~ if not ar.param_values.show_coming:
+                #~ qs = qs.exclude(applies_from__isnull=False,applies_from__gt=today)
+                
+        if ar.param_values.ending_success == dd.YesNo.yes:
+            qs = qs.filter(ending__isnull=False,ending__success=True)
+        elif ar.param_values.ending_success == dd.YesNo.no:
+            qs = qs.filter(ending__isnull=False,ending__success=False)
+            
+        if ar.param_values.ending is not None:
+            qs = qs.filter(ending=ar.param_values.ending)
+        #~ logger.info("20130524 %s",qs.query)
         return qs
     
     
+    @classmethod
+    def get_title_tags(self,ar):
+        for t in super(ContractBaseTable,self).get_title_tags(ar):
+            yield t
+            
+        if ar.param_values.observed_event:
+            yield unicode(ar.param_values.observed_event)
+        if ar.param_values.company:
+            yield unicode(ar.param_values.company)
+            
+
 
 
 class OverlappingContractsTest:
@@ -659,11 +747,35 @@ class Contracts(ContractBaseTable):
     client
     type company
     """,window_size=(60,'auto'))    
-    parameters = dict(
-      type = models.ForeignKey(ContractType,blank=True,verbose_name=_("Only contracts of type")),
-      **ContractBaseTable.parameters)
     
-
+    parameters = dict(
+      type = models.ForeignKey(ContractType,blank=True),
+      study_type = models.ForeignKey('isip.StudyType',blank=True),
+      **ContractBaseTable.parameters)
+      
+    params_layout = """
+    user type start_date end_date observed_event
+    company:20 study_type:15 ending_success:20 ending
+    """
+    
+    @classmethod
+    def get_request_queryset(cls,ar):
+        #~ logger.info("20120608.get_request_queryset param_values = %r",ar.param_values)
+        qs = super(Contracts,cls).get_request_queryset(ar)
+        if ar.param_values.study_type:
+            qs = qs.filter(study_type=ar.param_values.study_type)
+        return qs
+            
+    @classmethod
+    def get_title_tags(self,ar):
+        for t in super(Contracts,self).get_title_tags(ar):
+            yield t
+            
+        if ar.param_values.study_type:
+            yield unicode(ar.param_values.study_type)
+            
+      
+    
 class MyContracts(Contracts):
 #~ class MyContracts(Contracts,mixins.ByUser):
     #~ column_names = "applies_from client *"
@@ -694,12 +806,18 @@ class ContractsByPolicy(Contracts):
     master_key = 'exam_policy'
     #~ column_names = 'applies_from applies_until user type *'
 
-        
+       
 class ContractsByType(Contracts):
     master_key = 'type'
     column_names = "applies_from client user *"
     order_by = ["applies_from"]
 
+class ContractsByEnding(Contracts):
+    master_key = 'ending'
+    
+class ContractsByStudyType(Contracts):
+    master_key = 'study_type'
+    
 
 
 def customize_siteconfig():
