@@ -324,8 +324,10 @@ class Contract(isip.ContractBase):
     
     
     class Meta:
-        verbose_name = _("Job Contract")
-        verbose_name_plural = _('Job Contracts')
+        #~ verbose_name = _("Job Contract")
+        #~ verbose_name_plural = _('Job Contracts')
+        verbose_name = _("Art.60§7 contract")
+        verbose_name_plural = _('Art.60§7 contracts')
         
     type = models.ForeignKey("jobs.ContractType",
         related_name="%(app_label)s_%(class)s_set_by_type",
@@ -498,7 +500,7 @@ class Contract(isip.ContractBase):
         """
         Here's how to override the default verbose_name of a field.
         """
-        Contract.user.verbose_name=_("responsible (DSBE)")
+        Contract.user.verbose_name=_("responsible (IS)")
         #~ resolve_field('jobs.Contract.user').verbose_name=_("responsible (DSBE)")
         #~ lino.CONTRACT_PRINTABLE_FIELDS = dd.fields_list(cls,
         cls.PRINTABLE_FIELDS = dd.fields_list(cls,
@@ -581,6 +583,10 @@ class ContractsByType(Contracts):
     master_key = 'type'
     column_names = "applies_from client job user *"
     order_by = ["applies_from"]
+    
+class ContractsByEnding(Contracts):
+    master_key = 'ending'
+    
 
 class ContractsByJob(Contracts):
     column_names = 'client applies_from applies_until user type *'
@@ -1230,6 +1236,7 @@ class JobsOverview(dd.EmptyTable):
         #~ time.sleep(5)
         #~ today = self.date or datetime.date.today()
         today = ar.param_values.date or datetime.date.today()
+        period = (today,today)
         html = ''
         rows = []
           
@@ -1255,12 +1262,12 @@ class JobsOverview(dd.EmptyTable):
                             working.append(ct)
                             
                 qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.active)
-                qs = pcsw.only_coached_on(qs,today,'person')
+                qs = pcsw.only_coached_on(qs,period,'person')
                 for cand in qs:
                     candidates.append(cand)
                     
                 qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.probation)
-                qs = pcsw.only_coached_on(qs,today,'person')
+                qs = pcsw.only_coached_on(qs,period,'person')
                 for cand in qs:
                     probation.append(cand)
                     
@@ -1346,6 +1353,7 @@ class JobsOverviewByType(Jobs):
         data_rows = self.get_request_queryset(ar)
         
         today = ar.param_values.date or datetime.date.today()
+        period = (today,today)
         
         def UL(items):
             #~ return E.ul(*[E.li(i) for i in items])
@@ -1383,7 +1391,7 @@ class JobsOverviewByType(Jobs):
     
             candidates = []
             qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.active)
-            qs = pcsw.only_coached_on(qs,today,'person')
+            qs = pcsw.only_coached_on(qs,period,'person')
             for cand in qs:
                 candidates.append(cand)
             if candidates:
@@ -1397,7 +1405,7 @@ class JobsOverviewByType(Jobs):
                     
             probation = []
             qs = job.candidature_set.order_by('date_submitted').filter(state=CandidatureStates.probation)
-            qs = pcsw.only_coached_on(qs,today,'person')
+            qs = pcsw.only_coached_on(qs,period,'person')
             for cand in qs:
                 probation.append(cand)
             if probation:
@@ -1474,7 +1482,8 @@ if True: # dd.is_installed('contacts') and dd.is_installed('jobs'):
         """Whether this Company is also a Job Provider."""
         )
 
-MODULE_LABEL = _("Jobs")
+#~ MODULE_LABEL = _("Jobs")
+#~ MODULE_LABEL = _("Art.60§7")
 
 def setup_main_menu(site,ui,profile,m): 
     #~ if user.profile.integ_level < UserLevels.user:
