@@ -86,12 +86,8 @@ class Site(Site,cbss.SiteMixin):
         #~ """ % (self.label,lino.__url__)
         #~ return s
         
-    def get_main_action(self,user):
+    def unused_get_main_action(self,user): 
         return self.modules.lino.Home.default_action
-        #~ a = self.modules.lino.Home.default_action
-        #~ if a is None:
-            #~ raise Exception("20121004 self.modules.lino.Home.get_url_action('default_action') returned None")
-        #~ return a
         
     #~ def get_application_info(self):
         #~ return (__name__,__version__,__url__)
@@ -110,7 +106,7 @@ class Site(Site,cbss.SiteMixin):
         add('000', _("Anonymous"),                  '_ _ _ _ _ _', 
             name='anonymous', readonly=True,authenticated=False)
         add('100', _("Integration Agent"),          'U U U U _ _')
-        add('110', _("Integration Agent (Senior)"), 'U M M U _ _')
+        add('110', _("Integration Agent (Manager)"),'U M M U _ _')
         add('200', _("Newcomers consultant"),       'U U _ U U _')
         add('300', _("Debts consultant"),           'U U _ _ _ U')
         #~ add('400', _("Readonly Manager"),           'M M M M M M', readonly=True)
