@@ -24,8 +24,8 @@
 SETUP_INFO = dict(name='lino-welfare',
       #~ distclass=MyDistribution,
       #~ dist_dir=os.path.join('docs','dist'),
-      version='1.1.5', 
-      install_requires=['lino==1.6.8','suds','vobject'],
+      version='1.1.6', 
+      install_requires=['lino>=1.6.9','suds','vobject'],
       #~ version=VERSION,
       test_suite = 'tests',
       description=u"A Lino application for Belgian Public Welfare Centres",
@@ -148,6 +148,8 @@ add_package_data('lino_welfare.modlib.jobs','config/jobs/ContractsSituation/*.od
 add_package_data('lino_welfare.modlib.jobs','config/jobs/JobsOverview/*.odt')
 add_package_data('lino_welfare.modlib.jobs','config/jobs/NewJobsOverview/*.odt')
 add_package_data('lino_welfare.demo','media/pictures/contacts.Person.jpg')
+add_package_data('lino_welfare','config/lino_welfare/ActivityReport/*.odt')
+add_package_data('lino_welfare','templates_jinja/admin_main.html')
 #~ for n in (
     #~ 'lino_welfare', 
     #~ 'lino_welfare.modlib.courses',
